@@ -398,6 +398,19 @@ setup.add_option(
 Specifies the name of a directory to ignore when looking for tests.
 """)
 
+setup.add_option(
+    '--shuffle', action="store_true", dest='shuffle',
+    help="""\
+Shuffles the order in which tests are ran.
+""")
+
+setup.add_option(
+    '--shuffle-seed', action="store", dest='shuffle_seed', type="int",
+    help="""\
+Value used to initialize the tests shuffler. Specify a value to create
+repeatable random ordered tests.
+""")
+
 parser.add_option_group(setup)
 
 ######################################################################
@@ -405,13 +418,6 @@ parser.add_option_group(setup)
 
 other = optparse.OptionGroup(parser, "Other", "Other options")
 
-other.add_option(
-    '--exit-with-status', action="store_true", dest='exitwithstatus',
-    help="""\
-Return an error exit status if the tests failed.  This can be useful for
-an invoking process that wants to monitor the result of a test run.
-""")
-
 other.add_option(
     '-j', action="store", type="int", dest='processes',
     help="""\
@@ -444,6 +450,12 @@ tests against a tree where the .py files have been removed after
 compilation to .pyc/.pyo.  Use of this option implies --keepbytecode.
 """)
 
+other.add_option(
+    '--exit-with-status', action="store_true", dest='exitwithstatus',
+    help="""DEPRECATED: The test runner will always exit with a status.\
+""")
+
+
 parser.add_option_group(other)
 
 ######################################################################
